`timescale 1ns / 1ps
//////////////////////////////////////////////////////////////////////////////////
// Company: Digilent Inc.
// Engineers: Mircea Dabacan
//				  Mihai Corovei
//				  Josh Sackos
// 
// Create Date:    10:24:29 06/07/2012 
// Module Name:    Hb5RefProj - Mixt (Structural and Behavioral)
// Project Name:   Hb5RefProj
// Target Devices: Nexys3
// Tool versions:  ISE 14.1
// Description: This project demonstrates the use of the Digilent HB5 Reference 
//              Component, HB5RefComp, with a DC motor.
//              The SA and SB hall sensors signals are used, to calculate the 
//              speed of the motors.
//              The project can also be used with the Pmod HB3.
//              The above component is instantiated to control a Pmod HB5
//              The adjustBcd component provides a BCD value, adjustable with
//              btnFaster and btnSlower.
//              This value is used to set the duty factor of pinEn. The value is 
//              also shown on the 7 segment display.
//              swDir sets the direction for the motor, after being secured in
//              the HB5RefComp. The direction is also shown on the 7 segment 
//              display as "-" (for minus) or nothing (for plus).
//
// Dependencies: 
//
// Revision: 
// Revision 0.01 - File Created
// Additional Comments: 
//
//////////////////////////////////////////////////////////////////////////////////
module Hb5RefProj(
    ck,
    btnFaster,
    btnSlower,
    swDir,
    swSelDisp,
    pinSA,
    pinSB,
    pinEn,
    pinDir,
    seg,
    an
    );


	 // ===========================================================================
	 // 										Port Declarations
	 // ===========================================================================
    input ck;
    input btnFaster;
    input btnSlower;
    input swDir;
    input swSelDisp;
    input pinSA;
    input pinSB;
    output pinEn;
    output pinDir;
    output [6:0] seg;
    output [3:0] an;
	 
	 // ===========================================================================
	 // 							  Parameters, Regsiters, and Wires
	 // ===========================================================================
	 wire pinEn, pinDir;
	 wire [6:0] seg;
	 wire [3:0] an;
	 
	 wire [7:0] vecDf;
	 wire [12:0] Speed;
	 

	 // ===========================================================================
	 // 										Implementation
	 // ===========================================================================
 	 adjustBcd Inst_adjustBcd (
				  .ck(ck),
				  .bitCountUp(btnFaster),
				  .bitCountDown(btnSlower),
				  .vecBcdOut(vecDf)
	 );
	 
	 HB5RefComp Inst_HB5RefComp (
				  .ck(ck),
				  .bitDirIn(swDir),
				  .vecDfIn(vecDf),
				  .bitEnOut(pinEn),
				  .bitDirOut(pinDir)
	 );
	 
	 HallTradSpeedDecoder Inst_HallTradSpeedDecoder (
				  .ck(ck),
				  .pinSA(pinSA),
				  .pinSB(pinSB),
				  .SpeedOut(Speed)
	 );
	 
	 segDisplay Inst_segDisplay (
				  .ck(ck),
				  .vecDfIn(vecDf),
				  .swDir(swDir),
				  .SpeedIn(Speed),
				  .swSelDisp(swSelDisp),
				  .an(an),
				  .seg(seg)
	 );

endmodule
